@@ -380,6 +380,12 @@ on_first_timer (SeahorseKeyManager* self)
 	return FALSE;
 }
 
+static void
+on_clear_clicked (GtkEntry* entry, GtkEntryIconPosition icon_pos, GdkEvent* event, gpointer user_data)
+{
+	gtk_entry_set_text (entry, "");
+}
+
 static void 
 on_filter_changed (GtkEntry* entry, SeahorseKeyManager* self) 
 {
@@ -575,9 +581,13 @@ on_clipboard_received (GtkClipboard* board, const char* text, SeahorseKeyManager
 	g_return_if_fail (SEAHORSE_IS_KEY_MANAGER (self));
 	g_return_if_fail (GTK_IS_CLIPBOARD (board));
 	g_return_if_fail (text != NULL);
-	
-	if (text != NULL && g_utf8_strlen (text, -1) > 0)
-		import_text (self, text);
+
+    g_assert(self->pv->filter_entry);
+    if (gtk_widget_is_focus (GTK_WIDGET (self->pv->filter_entry)) == TRUE)
+	    gtk_editable_paste_clipboard (GTK_EDITABLE (self->pv->filter_entry));
+    else	
+    	if (text != NULL && g_utf8_strlen (text, -1) > 0)
+    		import_text (self, text);
 }
 
 static void 
@@ -835,7 +845,6 @@ seahorse_key_manager_set_selected (SeahorseViewer* base, SeahorseObject* value)
 	g_object_notify (G_OBJECT (self), "selected");
 }
 
-
 static GObject* 
 seahorse_key_manager_constructor (GType type, guint n_props, GObjectConstructParam *props) 
 {
@@ -878,7 +887,7 @@ seahorse_key_manager_constructor (GType type, guint n_props, GObjectConstructPar
 	seahorse_viewer_include_actions (SEAHORSE_VIEWER (self), self->pv->view_actions);
 	
 	/* Notify us when gconf stuff changes under this key */
-	seahorse_gconf_notify_lazy (LISTING_SCHEMAS, (GConfClientNotifyFunc)on_gconf_notify, self, GTK_OBJECT (self));
+	seahorse_gconf_notify_lazy (LISTING_SCHEMAS, (GConfClientNotifyFunc)on_gconf_notify, self, self);
 	
 	/* close event */
 	g_signal_connect_object (seahorse_widget_get_toplevel (SEAHORSE_WIDGET (self)), 
@@ -934,6 +943,23 @@ seahorse_key_manager_constructor (GType type, guint n_props, GObjectConstructPar
 			}
 		}
 	}
+
+	gtk_entry_set_icon_from_icon_name (self->pv->filter_entry,
+					   GTK_ENTRY_ICON_PRIMARY,
+					   GTK_STOCK_FIND);
+	gtk_entry_set_icon_from_icon_name (self->pv->filter_entry,
+					   GTK_ENTRY_ICON_SECONDARY,
+					   GTK_STOCK_CLEAR);
+
+	gtk_entry_set_icon_activatable (self->pv->filter_entry,
+					GTK_ENTRY_ICON_PRIMARY, FALSE);
+	gtk_entry_set_icon_activatable (self->pv->filter_entry,
+					GTK_ENTRY_ICON_SECONDARY, TRUE);
+
+	gtk_entry_set_width_chars (self->pv->filter_entry, 30);
+
+	g_signal_connect (self->pv->filter_entry, "icon-release",
+			  G_CALLBACK (on_clear_clicked), NULL);
 	
 	/* For the filtering */
 	g_signal_connect_object (GTK_EDITABLE (self->pv->filter_entry), "changed", 
